This function takes a data.table object as input and
translates the cds sequences stored as seqs column into the corresponding amino acid
sequence.
Arguments
- dt
a
data.tableobject storing cds sequences in a column namedseqs.- delete_corrupt_cds
a logical value indicating whether sequences with corrupt base triplets should be removed from the input
file. This is the case when the length of coding sequences cannot be divided by 3 and thus the coding sequence contains at least one corrupt base triplet.