This function takes CDS sequence as string as input an returns the corresponding amino acid sequence as string.
Examples
# an example DNA sequence
DNA <- c("ACCGGTTTAAAGGCGTTA")
# translating DNA to a protein sequence
transl(DNA)
#> [1] "TGLKAL"
This function takes CDS sequence as string as input an returns the corresponding amino acid sequence as string.
# an example DNA sequence
DNA <- c("ACCGGTTTAAAGGCGTTA")
# translating DNA to a protein sequence
transl(DNA)
#> [1] "TGLKAL"