Retrieve a core set of orthologous lncRNAs (deprecated)
Source:R/lnc_map_core_orthologs.R
lnc_map_core_orthologs.RdThis function is deprecated and will be removed in a future release.
Please use retrieve_core_orthologs instead, which now handles both
protein-coding gene tables and lncRNA maps automatically.
Arguments
- lnc_map
a
lnc_mapthat was generated withmap_generator_lnc.- species_order
a character string specifying species names listed in the order of phylogenetic/taxonomic distance from the query species.