Count number of orthologous lncRNAs per pairwise species comparison
Source:R/lnc_map_counts.R
lnc_map_counts.RdThis function takes a orthologous lncRNA map generated with map_generator_lnc
as input and groups the table by species to count the number of orthologous lncRNAs per pairwise species comparison
using the reference (query) species specified in map_generator_lnc.
Arguments
- lnc_map
a orthologous lncRNA map generated with
map_generator_lnc.- species_order
character string specifying species names listed in the order of phylogenetic/taxonomic distance from the query species. The species names must match with the species names present in
map_generator_lnc.