Estimate the DNA distance between promotor sequences
Source:R/promotor_divergence_estimation.R
promotor_divergence_estimation.RdGiven two fasta files storing the promotor sequence
of protein coding genes, this function estimates the pairwise DNA distance between these promotor sequences.
Arguments
- query
file path to a query
fastafile storing promotor sequences of interest (e.g. generated withextract_upstream_promotor_seqs).- subject
file path to a subject
fastafile storing promotor sequences of interest (e.g. generated withextract_upstream_promotor_seqs).- model
a model as specified in
dist.dna: a character string specifying the evolutionary model to be used - must be one of:K80(the default)rawNTSTVJC69F81K81F84BH87T92TN93GG95logdetparalin