Retrieve a core set of orthologous gene loci from several pairwise ortholog tables
Source:R/retrieve_core_orthologs.R
retrieve_core_orthologs.RdGiven a ortho table generated with generate_ortholog_tables_all,
this function will determine a core set of orthologs that are shared between all species.
Arguments
- ortho_tables
a
ortho tablesthat was generated withgenerate_ortholog_tables_all.- species_order
a character string specifying species names listed in the order of phylogenetic/taxonomic distance from the query species. The species names must match with the species names present in the
ortho_tables.